@@ -1,6 +1,6 @@
 package ExtUtils::Helpers::Unix;
 {
-  $ExtUtils::Helpers::Unix::VERSION = '0.010';
+  $ExtUtils::Helpers::Unix::VERSION = '0.011';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -12,13 +12,12 @@ use Text::ParseWords 3.24 qw/shellwords/;
 use ExtUtils::MakeMaker;
 
 sub make_executable {
-	my @files = @_;
-	foreach my $file (@files) {
-		my $current_mode = (stat $file)[2] + 0;
-		ExtUtils::MM->fixin($file) if -T $file;
-		chmod $current_mode | oct(111), $file;
-	}
-};
+	my $file = shift;
+	my $current_mode = (stat $file)[2] + 0;
+	ExtUtils::MM->fixin($file) if -T $file;
+	chmod $current_mode | oct(111), $file;
+	return;
+}
 
 sub split_like_shell {
   my ($string) = @_;
@@ -32,6 +31,8 @@ sub split_like_shell {
 
 1;
 
+# ABSTRACT: Unix specific helper bits
+
 
 
 =pod
@@ -42,7 +43,7 @@ ExtUtils::Helpers::Unix - Unix specific helper bits
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =for Pod::Coverage make_executable
 split_like_shell
@@ -73,5 +74,3 @@ the same terms as the Perl 5 programming language system itself.
 
 __END__
 
-# ABSTRACT: Unix specific helper bits
-
